==> genometools-1.0.3.tar.gz: genometools-1.0.3/src/libgtcore/ensure.h <==
/*
  Copyright (c) 2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef ENSURE_H
#define ENSURE_H

#include "libgtcore/env.h"

/* the ensure macro used for unit tests */
#define ensure(had_err, e)                                                     \
        do {                                                                   \
          if (!had_err) {                                                      \
            if (!(e)) {                                                        \
              env_error_set(env, "ensure \"%s\" failed: file \"%s\", line %d", \
                            #e, __FILE__, __LINE__);                           \
              had_err = -1;                                                    \
            }                                                                  \
          }                                                                    \
        } while (0)

#endif

==> genometools-1.0.8.tar.gz: genometools-1.0.8/src/libgtcore/ensure.h <==
/*
  Copyright (c) 2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef ENSURE_H
#define ENSURE_H

#include "libgtcore/error.h"

/* the ensure macro used for unit tests */
#define ensure(had_err, e)                                                     \
        do {                                                                   \
          if (!had_err) {                                                      \
            if (!(e)) {                                                        \
              error_set(err, "ensure \"%s\" failed: file \"%s\", line %d", #e, \
                        __FILE__, __LINE__);                                   \
              had_err = -1;                                                    \
            }                                                                  \
          }                                                                    \
        } while (0)

#endif
